From 21db9399234705549f518ec1838199ad675d1faf Mon Sep 17 00:00:00 2001
From: Burt Silverman <burtms@gmail.com>
Date: Sat, 7 Sep 2019 16:33:53 -0400
Subject: [PATCH] BaseTools: Robustness for multiple build environments

When building BaseTools, GNUmakefile builds create directory
BaseTools/Source/C/libs/. On the other hand, Makefile builds use libs
as an nmake pseudo target, so it either must NOT exist as a file or
directory, OR it must phony dependency like .PHONY. The latter
solution conflicts with NmakeSubdirs.py. Therefore, I make it go away
in the cleanall target. I could also add it to the clean target, but
it strikes me that cleanall should be more forceful.

Signed-off-by: Burt Silverman <burtms@gmail.com>
---
 BaseTools/Source/C/Makefile | 2 ++
 1 file changed, 2 insertions(+)

diff --git a/BaseTools/Source/C/Makefile b/BaseTools/Source/C/Makefile
index 217fc2b91d..e8f8abe59a 100644
--- a/BaseTools/Source/C/Makefile
+++ b/BaseTools/Source/C/Makefile
@@ -63,6 +63,8 @@ clean:
 cleanall:
   @if defined PYTHON_COMMAND $(PYTHON_COMMAND) Makefiles\NmakeSubdirs.py cleanall $(LIBRARIES) $(APPLICATIONS)
   @if not defined PYTHON_COMMAND $(PYTHON_HOME)\python.exe Makefiles\NmakeSubdirs.py cleanall $(LIBRARIES) $(APPLICATIONS)
+# Next line protects the libs pseudo target from inadvertent GNU make activity
+  if exist libs RMDIR /S /Q libs
 
 !INCLUDE Makefiles\ms.rule
 
-- 
2.23.0.windows.1

